@@ -292,7 +292,7 @@ DEMUX_PACKET* FFmpegStream::DemuxRead()
   // on some cases where the received packet is invalid we will need to return an empty packet (0 length) otherwise the main loop (in CVideoPlayer)
   // would consider this the end of stream and stop.
   bool bReturnEmpty = false;
-  { std::lock_guard<std::mutex> lock(m_mutex); // open lock scope
+  { std::lock_guard<std::recursive_mutex> lock(m_mutex); // open lock scope
   if (m_pFormatContext)
   {
     // assume we are not eof
@@ -792,9 +792,14 @@ bool FFmpegStream::Open(bool fileinfo)
 
   // select the correct program if requested
   m_initialProgramNumber = UINT_MAX;
-  CVariant programProp(m_programProperty);
-  if (!programProp.isNull())
-    m_initialProgramNumber = static_cast<int>(programProp.asInteger());
+  CVariant programProp;
+  if (!m_programProperty.empty())
+  {
+    CVariant programProp(m_programProperty);
+
+    if (!programProp.isNull() && programProp.isInteger())
+      m_initialProgramNumber = static_cast<int>(programProp.asInteger());
+  }
 
   // in case of mpegts and we have not seen pat/pmt, defer creation of streams
   if (!skipCreateStreams || m_pFormatContext->nb_programs > 0)
@@ -1415,11 +1420,27 @@ std::string FFmpegStream::ConvertCodecToInternalStereoMode(const std::string &mo
 
 void FFmpegStream::StoreSideData(DEMUX_PACKET *pkt, AVPacket *src)
 {
-  AVPacket avPkt;
-  av_init_packet(&avPkt);
-  av_packet_copy_props(&avPkt, src);
-  pkt->pSideData = avPkt.side_data;
-  pkt->iSideDataElems = avPkt.side_data_elems;
+  AVPacket* avPkt = av_packet_alloc();
+  if (!avPkt)
+  {
+    Log(LOGLEVEL_ERROR, "FFmpegStream::{} - av_packet_alloc failed: {}", __FUNCTION__, strerror(errno));
+  }
+  else
+  {
+    // here we make allocate an intermediate AVPacket to allow ffmpeg to allocate the side_data
+    // via the copy below. we then reference this allocated memory in the DemuxPacket. this behaviour
+    // is bad and will require a larger rework.
+    av_packet_copy_props(avPkt, src);
+    pkt->pSideData = avPkt->side_data;
+    pkt->iSideDataElems = avPkt->side_data_elems;
+
+    //! @todo: properly handle avpkt side_data. this works around our inproper use of the side_data
+    // as we pass pointers to ffmpeg allocated memory for the side_data. we should really be allocating
+    // and storing our own AVPacket. This will require some extensive changes.
+    // tl;dr: it frees the packet but not the side data.
+    av_buffer_unref(&avPkt->buf);
+    av_free(avPkt);
+  }
 }
 
 bool FFmpegStream::SeekTime(double time, bool backwards, double* startpts)
@@ -1471,7 +1492,7 @@ bool FFmpegStream::SeekTime(double time, bool backwards, double* startpts)
 
   int ret;
   {
-    std::lock_guard<std::mutex> lock(m_mutex);
+    std::lock_guard<std::recursive_mutex> lock(m_mutex);
     ret = av_seek_frame(m_pFormatContext, m_seekStream, seek_pts, backwards ? AVSEEK_FLAG_BACKWARD : 0);
 
     if (ret < 0)
